/*
    This file is part of Rocs.
    Copyright 2008-2009  Tomaz Canabrava <tomaz.canabrava@gmail.com>
    Copyright 2008       Ugo Sangiori <ugorox@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SUI_SEPARATOR_H
#define SUI_SEPARATOR_H

#include <QWidget>

class Separator : public QWidget
{
public:
    Separator(QWidget* parent);
    QSize sizeHint() const ;
    void paintEvent(QPaintEvent *) ;
};
#endif
